Support
=======

If you have questions or need help with testinfra please consider one of the
following

Issue Tracker
~~~~~~~~~~~~~

Checkout existing issues on `project issue tracker <https://github.com/philpep/testinfra/issues>`_

IRC
~~~

You can also ask questions on IRC in `#testinfra <http://webchat.freenode.net/?randomnick=1&channels=%23testinfra>`_ channel on Freenode

pytest documentation
~~~~~~~~~~~~~~~~~~~~

testinfra is implemented as pytest plugin so to get the most out of please
read `pytest documentation <http://pytest.org>`_

Community Contributions
~~~~~~~~~~~~~~~~~~~~~~~

* `Molecule <http://molecule.readthedocs.io>`_ is an Automated testing framework for Ansible roles, with native Testinfra support.
